BPWdtDPclAutwdCF class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

AcrPnCDxNAuKlANw({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required String zVQcgWvKZtkJMnYp, required String XeyywgjLrvEJDGig, String? luRVawEWUiAwJYPI, int? HloRAPYKmHNfLRQU, YIMPushOption? iJJJYNStYhEVSDaC = null, void DvvEwdOxBkxNriZn(YIMMessage message)?, void YkHxkreSPTiwOMcu(YIMMessage message, int count, int total)?, void dLigQDgTTEAlDBZc(bool jBJRYhzkvpgxIyJB, YIMMessage message, int code, String msg)?}) Future<void>
override
amACyXYqzKVCEEMz({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required String XtJckoExyIhUmQyb, YIMPushOption? iJJJYNStYhEVSDaC = null, bool wNOkQgnUkXbqDcup = false, void DvvEwdOxBkxNriZn(YIMMessage message)?, void dLigQDgTTEAlDBZc(bool jBJRYhzkvpgxIyJB, YIMMessage message, int code, String msg)?}) → void
override
bWSMCaLqZvpPAPLp({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required String zVQcgWvKZtkJMnYp, bool PvcvECswKJfElWOt = true, required int IfcebQVAGtqMWgHR, String? luRVawEWUiAwJYPI, int? HloRAPYKmHNfLRQU, YIMPushOption? iJJJYNStYhEVSDaC = null, void DvvEwdOxBkxNriZn(YIMMessage message)?, void YkHxkreSPTiwOMcu(YIMMessage message, int count, int total)?, void dLigQDgTTEAlDBZc(bool jBJRYhzkvpgxIyJB, YIMMessage message, int code, String msg)?}) Future<void>
override
CjrwuCRGCgcxUbuo({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required List<String> PmicSLnKQEgxpVCO}) Future<void>
override
cMEicGHyBaBHPjAL({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required List<String> PmicSLnKQEgxpVCO, required void YTEypayopzJvIBUA(List<YIMMessage>? messages)}) Future<void>
override
dzoBUWirOgkEntCq({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd}) Future<void>
override
eNTliiyPMGPfvTgm({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required String KeeYyrGlHjtCSrXV, void YTEypayopzJvIBUA(bool jBJRYhzkvpgxIyJB)?}) → void
override
FpVHmjxfGDwsptcT({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, void YTEypayopzJvIBUA(bool jBJRYhzkvpgxIyJB)?}) → void
override
GFGVCOgBnqJtEoQB({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, void YTEypayopzJvIBUA(bool jBJRYhzkvpgxIyJB)?}) → void
override
jhZJpetRGXqMQOig({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required String KeeYyrGlHjtCSrXV, required void YTEypayopzJvIBUA(YIMMessage? message)}) → void
override
JRnSpusTdpDriPVX({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, DateTime? jJndINKrAckEOYgB, bool fqBMtvGaaBvObyxG = false, int UdmLlxrIYrluzDgl = 20, YIMEnum_QueryDirection iNRZRmUXUzVIUKql = YIMEnum_QueryDirection.Old, required void YTEypayopzJvIBUA(List<YIMMessage>? messages)}) Future<void>
override
lEiqqnuUDMgArGWu(YIMEnum_ConversationType CWQdcqrbDuFebimL, String KeeYyrGlHjtCSrXV) Future<bool>
override
LUtuvbNmqMtRwSnw({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required String zVQcgWvKZtkJMnYp, bool PvcvECswKJfElWOt = true, String? luRVawEWUiAwJYPI, int? HloRAPYKmHNfLRQU, YIMPushOption? iJJJYNStYhEVSDaC = null, void DvvEwdOxBkxNriZn(YIMMessage message)?, void YkHxkreSPTiwOMcu(YIMMessage message, int count, int total)?, void dLigQDgTTEAlDBZc(bool jBJRYhzkvpgxIyJB, YIMMessage message, int code, String msg)?}) Future<void>
override
NFRCExmfuaboWpZg({required YIMMessage BgNqajmtiJcHpecT}) Future<void>
override
NIAQIhCrSPmofNZc({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required String KeeYyrGlHjtCSrXV}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
QeOsXHFeMJRreVBl({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required YIMEnum_MessageType wnmeCtBLhLQmyVnD, String? XtJckoExyIhUmQyb, String? luRVawEWUiAwJYPI, YIMAttachment? jigHuOzYLCreGbUs, YIMPushOption? iJJJYNStYhEVSDaC = null, bool wNOkQgnUkXbqDcup = false, void DvvEwdOxBkxNriZn(YIMMessage message)?, void YkHxkreSPTiwOMcu(YIMMessage message, int count, int total)?, void dLigQDgTTEAlDBZc(bool jBJRYhzkvpgxIyJB, YIMMessage message, int code, String msg)?}) Future<void>
override
TjAHnXrlvrqwaznH(YIMEnum_ConversationType CWQdcqrbDuFebimL, String JjzDsQzKwhJEVLQd, bool VDVycsusrrQMPTce) Future<bool>
override
toString() String
A string representation of this object.
inherited
uGicwjhemoBDdfHv({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required String XtJckoExyIhUmQyb, YIMPushOption? iJJJYNStYhEVSDaC = null, void DvvEwdOxBkxNriZn(YIMMessage message)?, void dLigQDgTTEAlDBZc(bool jBJRYhzkvpgxIyJB, YIMMessage message, int code, String msg)?}) → void
override
WUcWNAwivWwdvCnN({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, DateTime? jJndINKrAckEOYgB, int UdmLlxrIYrluzDgl = 20, YIMEnum_QueryDirection iNRZRmUXUzVIUKql = YIMEnum_QueryDirection.Old, required void YTEypayopzJvIBUA(bool jBJRYhzkvpgxIyJB, List<YIMMessage>? messages)}) → void
override
xVAqkaJQNBnfHTKU({required YIMEnum_ConversationType CWQdcqrbDuFebimL, required String JjzDsQzKwhJEVLQd, required String zVQcgWvKZtkJMnYp, required int IfcebQVAGtqMWgHR, String? luRVawEWUiAwJYPI, int? HloRAPYKmHNfLRQU, YIMPushOption? iJJJYNStYhEVSDaC = null, void DvvEwdOxBkxNriZn(YIMMessage message)?, void YkHxkreSPTiwOMcu(YIMMessage message, int count, int total)?, void dLigQDgTTEAlDBZc(bool jBJRYhzkvpgxIyJB, YIMMessage message, int code, String msg)?}) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

pswBomDlyQuGiTdm BPWdtDPclAutwdCF
final