UdDLEyXnZJjzJpbv class

Inheritance

Properties

bNtqOyRWxOrowAZX ↔ void Function(List<YIMConversation> conversations)?
getter/setter pairinherited
cBVOMoXdTyThFcRk ↔ void Function(YIMRevokeMessage revokeMessage)?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hJyRATsSappwYemU ↔ void Function(YIMBroadcastMessage broadcastMessage)?
getter/setter pairinherited
ILHvgzQbwdReWqoO ↔ void Function(List<YIMConversation> conversations)?
getter/setter pairinherited
LbyRSdHpXqCWsHGc ↔ void Function(YIMPushMessage pushMessage)?
getter/setter pairinherited
LPyyKzRzgEgTinGo ↔ void Function(List<YIMMessage> messages)?
getter/setter pairinherited
MjNWSNzSPevgJqfi ↔ void Function(YIMResult<YIMEnum_OnlineState> result)?
getter/setter pairinherited
NulXGAZapqyEQTYU ↔ void Function(String roomID)?
getter/setter pairinherited
oWIofSIWdiLwyDfi ↔ void Function(List<YIMConversation> conversations)?
getter/setter pairinherited
pBICbrHbRPrMoVKu ↔ void Function(List<YIMMessage> messages)?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snFtgQoanrvKZGbH ↔ void Function(YIMNotificationMessage notificationMessage)?
getter/setter pairinherited
UUHdWrrAJtOmFFHX ↔ void Function(String conversationID)?
getter/setter pairinherited
vbkGgBUjJANFBecG ↔ void Function()?
getter/setter pairinherited
YOtybFJQmFLWOppZ ↔ void Function(String roomID)?
getter/setter pairinherited

Methods

askrwHpSJNQhGWkJ({required void OMKwYKeBBFVoTNBl(List<YIMConversation> conversations)}) → void
override
BjfHTkZlctCsPnIR() → void
override
boMENuWxxmnYbfvf({required void OMKwYKeBBFVoTNBl(List<YIMMessage> messages)}) → void
override
ceNFZEkivBnLuWis() → void
override
clcMdfWSgaLXGnsh({required void OMKwYKeBBFVoTNBl(YIMBroadcastMessage broadcastMessage)}) → void
override
clYmVguFzfgVFxfT() → void
override
CMyCFnlxGSkpBMef() → void
override
gfeuMjYZBYfBxLTq() → void
override
IDZGEsVGqsbbWAfF({required void OMKwYKeBBFVoTNBl(YIMNotificationMessage notificationMessage)}) → void
override
IPtDSpESbVSbvDYg() → void
override
klkPEkZZSZnzeZBF({required void OMKwYKeBBFVoTNBl(List<YIMConversation> conversations)}) → void
override
ksrsKayrxbtCLiRT({required void OMKwYKeBBFVoTNBl(YIMRevokeMessage revokeMessage)}) → void
override
KzrIpmMZZtqGhzHC({required void OMKwYKeBBFVoTNBl(YIMResult<YIMEnum_OnlineState> result)}) → void
override
mdoEsDfryrbBWXaZ() → void
override
NEZMsadlJTQIybdM() → void
override
nmNpkbAYvPQmbqTo() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
oxdqiJRAyQLrnfZf({required void OMKwYKeBBFVoTNBl(List<YIMConversation> conversations)}) → void
override
PqFHkSeTdhsjIpRd() → void
override
PQojbphryJzMqoeP() → void
override
PtTUBBAAIjMKZggF({required void OMKwYKeBBFVoTNBl(String roomID)}) → void
override
QfShFxjtVkwOmrEJ({required void OMKwYKeBBFVoTNBl()}) → void
override
TazWGotrNldZXEyo({required void OMKwYKeBBFVoTNBl(String conversationID)}) → void
override
toString() String
A string representation of this object.
inherited
uEYCYmsunBxIztci() → void
override
WAlcrzDTdZeUlwGx({required void OMKwYKeBBFVoTNBl(String roomID)}) → void
override
WILARUpqRTRrvjOj({required void OMKwYKeBBFVoTNBl(List<YIMMessage> messages)}) → void
override
wxFoTxzoqUxjWAnV() → void
override
xbXCGyMjqztfblae({required void OMKwYKeBBFVoTNBl(YIMPushMessage pushMessage)}) → void
override
YZcbFKSyTmomAFgG() → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

JAzABuKdZZWyhxVy UdDLEyXnZJjzJpbv
final