jccDnlKMlmSWgcsN class abstract

Implementers

Constructors

jccDnlKMlmSWgcsN()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

AQtXHkZaZVyAnHbm({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required String QZRDZLTQRhjGMFri, void dFOzKXrUQFAiVUMV(bool IWxelvVBXdhLiYGw)?}) → void
CBjapngMjhQiNExq({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, DateTime? BZOczrjwvuQuZcVB, int nHycbSwpLhrSWLwd = 20, YIMEnum_QueryDirection kDSsmTIGtYAcFzOA = YIMEnum_QueryDirection.Old, required void dFOzKXrUQFAiVUMV(bool IWxelvVBXdhLiYGw, List<YIMMessage>? messages)}) → void
CjBnZnOrLqwWPnFL({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, void dFOzKXrUQFAiVUMV(bool IWxelvVBXdhLiYGw)?}) → void
EwGdGccfuNRryaZL({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required String iTYbTOvgPjQlKLzR, required int EtobKhypxMKtLcsB, String? UZjQPwKKBftipoNw, int? vuskAjdCVVUFylrN, YIMPushOption? uHrDKqGhYwFfFjzt = null, void oEwVYbdGNiYrQhbg(YIMMessage message)?, void WmGDNPHAWOMlPvEy(YIMMessage message, int count, int total)?, void dNSrphLqsPPgGsKF(bool IWxelvVBXdhLiYGw, YIMMessage message, int code, String msg)?}) Future<void>
FZbrYwBIceOzhxPF({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required List<String> TDAyyywicMtSIQVe, required void dFOzKXrUQFAiVUMV(List<YIMMessage>? messages)}) Future<void>
hfYXZhZXmRZURbDS({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, void dFOzKXrUQFAiVUMV(bool IWxelvVBXdhLiYGw)?}) → void
ifIWpDeVqjJUEklq({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, DateTime? BZOczrjwvuQuZcVB, bool JGOMXvVIllmZTJee = false, int nHycbSwpLhrSWLwd = 20, YIMEnum_QueryDirection kDSsmTIGtYAcFzOA = YIMEnum_QueryDirection.Old, required void dFOzKXrUQFAiVUMV(List<YIMMessage>? messages)}) Future<void>
JIqPgRlOlgMpHQUW({required YIMMessage kCwocHxVzlSDCcUI}) Future<void>
KBzcdMaVgeTLhbSO(YIMEnum_ConversationType TIVvnmucZCCCoXWZ, String DdEJLInBukyevMKs, bool vouKRcYFvxhACvav) Future<bool>
kYBDeeZGhHcHnUeV({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required String QZRDZLTQRhjGMFri}) → void
LBDUMPMaFHBqhdoR({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs}) Future<void>
McZszbMySCnQHMlt({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required String iTYbTOvgPjQlKLzR, required String nzHLtsCGaSjcSauH, String? UZjQPwKKBftipoNw, int? vuskAjdCVVUFylrN, YIMPushOption? uHrDKqGhYwFfFjzt = null, void oEwVYbdGNiYrQhbg(YIMMessage message)?, void WmGDNPHAWOMlPvEy(YIMMessage message, int count, int total)?, void dNSrphLqsPPgGsKF(bool IWxelvVBXdhLiYGw, YIMMessage message, int code, String msg)?}) Future<void>
mYKaFYUjvYZOWuZB({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required YIMEnum_MessageType EiRjaLJyoekAXvfO, String? VNXtVBoZudfncesZ, String? UZjQPwKKBftipoNw, YIMAttachment? yAxgAMAldXwbyuHy, YIMPushOption? uHrDKqGhYwFfFjzt = null, bool eFLZtwaPtnBZJJFl = false, void oEwVYbdGNiYrQhbg(YIMMessage message)?, void WmGDNPHAWOMlPvEy(YIMMessage message, int count, int total)?, void dNSrphLqsPPgGsKF(bool IWxelvVBXdhLiYGw, YIMMessage message, int code, String msg)?}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
NotNcXpzkZPBxlcl({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required String VNXtVBoZudfncesZ, YIMPushOption? uHrDKqGhYwFfFjzt = null, bool eFLZtwaPtnBZJJFl = false, void oEwVYbdGNiYrQhbg(YIMMessage message)?, void dNSrphLqsPPgGsKF(bool IWxelvVBXdhLiYGw, YIMMessage message, int code, String msg)?}) → void
oIwrynAQRXgIRlXj({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required String iTYbTOvgPjQlKLzR, bool XonrGWjTpqOPuBKd = true, String? UZjQPwKKBftipoNw, int? vuskAjdCVVUFylrN, YIMPushOption? uHrDKqGhYwFfFjzt = null, void oEwVYbdGNiYrQhbg(YIMMessage message)?, void WmGDNPHAWOMlPvEy(YIMMessage message, int count, int total)?, void dNSrphLqsPPgGsKF(bool IWxelvVBXdhLiYGw, YIMMessage message, int code, String msg)?}) Future<void>
oTdXwkAKmpvktxnB({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required String iTYbTOvgPjQlKLzR, bool XonrGWjTpqOPuBKd = true, required int EtobKhypxMKtLcsB, String? UZjQPwKKBftipoNw, int? vuskAjdCVVUFylrN, YIMPushOption? uHrDKqGhYwFfFjzt = null, void oEwVYbdGNiYrQhbg(YIMMessage message)?, void WmGDNPHAWOMlPvEy(YIMMessage message, int count, int total)?, void dNSrphLqsPPgGsKF(bool IWxelvVBXdhLiYGw, YIMMessage message, int code, String msg)?}) Future<void>
pxGoRhRpYagFTfeH({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required String VNXtVBoZudfncesZ, YIMPushOption? uHrDKqGhYwFfFjzt = null, void oEwVYbdGNiYrQhbg(YIMMessage message)?, void dNSrphLqsPPgGsKF(bool IWxelvVBXdhLiYGw, YIMMessage message, int code, String msg)?}) → void
toString() String
A string representation of this object.
inherited
UzBNTmnyYLiVoGiK({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required List<String> TDAyyywicMtSIQVe}) Future<void>
VRCPzHDUoPYMLBOp(YIMEnum_ConversationType TIVvnmucZCCCoXWZ, String QZRDZLTQRhjGMFri) Future<bool>
YlKJnarwWgEReUCr({required YIMEnum_ConversationType TIVvnmucZCCCoXWZ, required String DdEJLInBukyevMKs, required String QZRDZLTQRhjGMFri, required void dFOzKXrUQFAiVUMV(YIMMessage? message)}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited