nnLscusjcLLwWwNR class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aeWeFGSbujdXKSBV({required YIMEnum_ConversationType UrZOeISLgYGOzZvq, required String XJcQJSIrkFDOfMQj, bool ASKBbIGYCJtaVefo = true, void PjjfSRUstyhbfrug(bool itdoxVdAckPoDbJI)?}) Future<void>
override
CVdgrXWZQzihlMXh({bool ASKBbIGYCJtaVefo = true, void PjjfSRUstyhbfrug(bool itdoxVdAckPoDbJI)?}) Future<void>
override
dUeNvsRpfxzyPOKv(YIMEnum_ConversationType UrZOeISLgYGOzZvq, String XJcQJSIrkFDOfMQj, {PDxpAagLlqdPhFRe HuXzMiqIkglfuhTS = PDxpAagLlqdPhFRe.IztLJZdmuaJaStJi}) Future<bool>
override
ERHeIaYSCunxsRHT({required YIMEnum_ConversationType UrZOeISLgYGOzZvq, required String XJcQJSIrkFDOfMQj, void PjjfSRUstyhbfrug(bool itdoxVdAckPoDbJI)?}) → void
override
lybdlWkMdsRQXXgn({required YIMEnum_ConversationType UrZOeISLgYGOzZvq, required String XJcQJSIrkFDOfMQj, bool ASKBbIGYCJtaVefo = true, void PjjfSRUstyhbfrug(bool itdoxVdAckPoDbJI)?}) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
PgQRWhveMXxinQKQ({required YIMEnum_ConversationType UrZOeISLgYGOzZvq, required String XJcQJSIrkFDOfMQj, void PjjfSRUstyhbfrug(bool itdoxVdAckPoDbJI)?}) → void
override
ROXJBmCFqAaDwZok({required void PjjfSRUstyhbfrug(List<YIMConversation>? conversations)}) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

UJMVbnnlRBhSIbbb nnLscusjcLLwWwNR
final