MGalMEnQijJLSfAs class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
anPqdZrnWKekLPyp(
{bool XnbKaMhmJjWKgrAm = false}) → bool -
GFPNACrtAeHgLKcF(
{required String OqUWRJxUkloqziqW, void dFOzKXrUQFAiVUMV(bool IWxelvVBXdhLiYGw)?}) → void -
JJPGEIqVXgtuBWXJ(
{required void dFOzKXrUQFAiVUMV(List< String> ? gvuZXqJUdGzyfXoC)}) → void -
KeQHbgwVXHqmhoYC(
{required String OqUWRJxUkloqziqW, required String kVCrbAsRrXnFJyNR, void dFOzKXrUQFAiVUMV(YIMResult< YIMEnum_LoginResult> result)?}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tjCgRWhndvkenDTj(
{required String OqUWRJxUkloqziqW, required void dFOzKXrUQFAiVUMV(bool IWxelvVBXdhLiYGw, YIMUser? user)}) → void -
toString(
) → String -
A string representation of this object.
inherited
-
uuXXzTCFXXQSupFS(
{required String OqUWRJxUkloqziqW, void dFOzKXrUQFAiVUMV(bool IWxelvVBXdhLiYGw)?}) → void -
YqhLoIVTiPFNjYVF(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited