owZaojSylngUTvpx class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
HeSfQKHUbsNZvgyZ(
{required void OMKwYKeBBFVoTNBl(List< String> ? sCeNNrYxNUhRvBXY)}) → void -
jJRNswwFkUSUgnYw(
{required String vYAButZFzjCwwdzm, void OMKwYKeBBFVoTNBl(bool oTLKfnnymNCTXHML)?}) → void -
KJxpwwVnHdOhAIQz(
{required String vYAButZFzjCwwdzm, required void OMKwYKeBBFVoTNBl(bool oTLKfnnymNCTXHML, YIMTeam? team)}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wgMpcaRCZOrRcvRt(
{required String vYAButZFzjCwwdzm, void OMKwYKeBBFVoTNBl(bool oTLKfnnymNCTXHML)?}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited